@@ -225,6 +225,16 @@ test_that("number_timeseries works", {
     c("auto=0", "auto=5029"),
     c("auto=5363", "auto=0")
   ) # rhub ubuntu
+  ans5 <- stringr::str_replace(
+    ans0,
+    c("auto=0", "auto=5029"),
+    c("auto=574", "auto=0")
+  ) # CRAN solaris
+  ans6 <- stringr::str_replace(
+    ans0,
+    c("auto=0", "auto=5029"),
+    c("auto=5214", "auto=0")
+  ) # CRAN Windows oldrel
   lfnts <- list.files("number_timeseries")
   if (all(lfnts %in% ans0)) {
     expect_true(all(lfnts %in% ans0))
@@ -236,10 +246,14 @@ test_that("number_timeseries works", {
     expect_true(all(lfnts %in% ans3))
   } else if (all(lfnts %in% ans4)) {
     expect_true(all(lfnts %in% ans4))
+  } else if (all(lfnts %in% ans5)) {
+    expect_true(all(lfnts %in% ans5))
+  } else if (all(lfnts %in% ans6)) {
+    expect_true(all(lfnts %in% ans6))
   } else {
     expect_equal(sort(lfnts), sort(ans0))
   }
-  suppressWarnings(file.remove(list.files())) # cleanup
+  suppressWarnings(file.remove(list.files(pattern = "\\.tiff*"))) # cleanup
   filesstrings::dir.remove("number_timeseries", "tempwithintemp")
   setwd(cwd)
 })
